summaryrefslogtreecommitdiffhomepage
path: root/dev/kernel/KernelKit/Semaphore.h
diff options
context:
space:
mode:
Diffstat (limited to 'dev/kernel/KernelKit/Semaphore.h')
-rw-r--r--dev/kernel/KernelKit/Semaphore.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/dev/kernel/KernelKit/Semaphore.h b/dev/kernel/KernelKit/Semaphore.h
index ac810c62..dffa1747 100644
--- a/dev/kernel/KernelKit/Semaphore.h
+++ b/dev/kernel/KernelKit/Semaphore.h
@@ -10,7 +10,7 @@
#include <KernelKit/Timer.h>
#include <CompilerKit/CompilerKit.h>
-namespace NeOS
+namespace Kernel
{
typedef Int64 Semaphore;
-} // namespace NeOS \ No newline at end of file
+} // namespace Kernel \ No newline at end of file